#!/usr/pkg/bin/perl

use strict;
use warnings;

use FindBin ();
use lib ("$FindBin::Bin/../testlib");
use lib ("./../testlib");

use Getopt::Long qw(:config bundling);
use Data::Dumper ('Dumper');
use Pod::Usage   ('pod2usage');

use run_tests    ();

my %cmdOptions = ();
GetOptions( \%cmdOptions,
	    "help|h" => sub { pod2usage(0); },
	    "items|i=i@" =>,
	  ) or exit(1);

my $test_prog = "$FindBin::Bin/multi_threaded_test";
chdir($FindBin::Bin);

my $tester = run_tests->new( $test_prog );
my $test_variants;
foreach my $item_count (@{$cmdOptions{items}}) {
	push( @$test_variants, $tester->get_test_combinations( $item_count ) );
}
$tester->run_tests( \@ARGV, $test_variants );

=head1 NAME

run_tests (script) - runs the multi-threaded tests

=head1 DESCRIPTION

This I<run_tests> script runs the multi-threaded tests for libstatgrab.

=head1 SYNOPSIS

  # run all functions alone and all 2-tuple, each in 3 threads
  $ tests/multi_threaded/run_tests --items 1 --items 2 -- -m 3

  # run all 4-tuple of libstatgrab functions, use at least 40 threads
  $ tests/multi_threaded/run_tests --items 4 -- -n 40

  # run all 7-tuple of libstatgrab functions, each in 5 threads but
  # sequencial function execution
  $ tests/multi_threaded/run_tests --items 4 -- -m 5 -s 1


=head1 OPTIONS

=over 8

=item C<--items|-i>

Specify how amount of I<libstatgrab>'s functions to test. All possible
combinations of k elements from n functions are generated and passed to
C<multi_threaded_test>.

=item C<-->

Separator for options passed directly to C<multi_threaded_test>.

=back

=over 4

=item *

The options of C<multi_threaded_test> can be seen when running
C<tests/multi_threaded/multi_threaded_test> with the C<-h> option.

=item *

The available libstatgrab functions of C<multi_threaded_test> can be seen
when running C<tests/multi_threaded/multi_threaded_test> with the
C<-l> option.

=back

=head1 AUTHOR

Jens Rehsack <sno@NetBSD.org>

=cut

